@@ -12,9 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import time
-import signal
 
 from acryl.executor.execution.default_executor import DefaultExecutor, DefaultExecutorConfig
 from acryl.executor.execution.task import TaskConfig
@@ -22,12 +20,8 @@ from acryl.executor.request.signal_request import SignalRequest
 from acryl.executor.request.execution_request import ExecutionRequest
 from acryl.executor.result.execution_result import ExecutionResult, Type
 from acryl.executor.secret.secret_store import SecretStoreConfig
-from datahub.metadata.schema_classes import ExecutionRequestResultClass, ExecutionRequestKeyClass, ExecutionRequestSignalClass, StructuredExecutionReportClass
-from datahub.metadata.com.linkedin.pegasus2avro.mxe import (
-    GenericAspectClass
-)
+from datahub.metadata.schema_classes import ExecutionRequestResultClass, ExecutionRequestKeyClass, StructuredExecutionReportClass
 from datahub.emitter.mcp import MetadataChangeProposalWrapper
-from datahub.emitter.serialization_helper import pre_json_transform
 from datahub.ingestion.graph.client import DataHubGraph, DatahubClientConfig
 from typing import List, Optional
 from pydantic import validator
