@@ -16,7 +16,6 @@ from asyncio import tasks
 from datetime import datetime, timedelta
 import os
 import sys
-import subprocess
 import logging
 import asyncio
 from collections import deque
@@ -132,6 +131,11 @@ class SubProcessIngestionTask(Task):
                 create_new_line = line.endswith('\n')
 
                 current_line_length = len(stdout_lines[-1])
+                if current_line_length == 0:
+                    # If we're at the beginning of a new line, scan for the error signature
+                    # of memory issues.
+                    if line.startswith('/usr/local/bin/run_ingest.sh:') and 'Killed' in line:
+                        ctx.get_report().report_error('The ingestion process was killed, likely because it ran out of memory. You can resolve this issue by allocating more memory to the datahub-actions container.')
                 if current_line_length < SubProcessTaskUtil.MAX_BYTES_PER_LINE:
                     allowed_length = SubProcessTaskUtil.MAX_BYTES_PER_LINE - current_line_length
                     if len(line) > allowed_length:
@@ -215,7 +219,7 @@ class SubProcessIngestionTask(Task):
                 with open(report_out_file,'r') as structured_report_fp:
                     ctx.get_report().set_structured_report(structured_report_fp.read())
 
-            ctx.get_report().report_info(f"stdout={SubProcessTaskUtil._format_log_lines(stdout_lines)}", log=False)
+            ctx.get_report().set_logs(SubProcessTaskUtil._format_log_lines(stdout_lines))
             
             # Cleanup by removing the recipe file
             SubProcessTaskUtil._remove_directory(exec_out_dir)
