@@ -32,17 +32,25 @@ class SubProcessTaskUtil:
     MAX_LOG_LINES = 2000
 
     # The original value is 64kb (https://github.com/python/cpython/blob/7528e2c06c8baf809b56f406bcc50e8436c9647c/Lib/asyncio/streams.py#L23).
-    # We are increasing it to 1mb, which should improve performance.
-    SUBPROCESS_BUFFER_SIZE = 2 ** 20
+    # Increasing it should improve performance.
+    SUBPROCESS_BUFFER_SIZE = 2 ** 20  # 1mb
 
-    # Since GMS has a 4mb limit on the size of a data packet, we want
-    # to truncate long lines.
+    # GMS / mysql has a 4mb limit on the size of a data packet.
+    # Doing 90% of that so we have some buffer.
+    MAX_LOG_SIZE_BYTES = int(0.9 * 2 ** 22)  # 90% of 4mb
+
+    # We want to truncate long lines so that we can show more lines in the logs.
     MAX_BYTES_PER_LINE = 2 ** 12  # 4kb
 
     @staticmethod
     def _format_log_lines(lines: Sequence[str]) -> str: 
         text = "".join(lines)
+
+        # Python slices are super permissive on index bounds, so this works.
+        text = text[-SubProcessTaskUtil.MAX_LOG_SIZE_BYTES:]
+
         if len(lines) >= SubProcessTaskUtil.MAX_LOG_LINES:
+            # lines is a deque, so len(lines) won't be larger than MAX_LOG_LINES.
             text = f"[earlier logs truncated...]\n{text}"
 
         return text
