@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pprint
-
+import contextlib
+import json
 from enum import Enum
-from acryl.executor.report.execution_report import ExecutionReport
 from acryl.executor.context.execution_context import ExecutionContext
-from typing import List, Optional
- 
+from typing import Optional
+
+
 class Type(Enum):
     SUCCESS = 1
     FAILURE = 2
@@ -26,12 +26,13 @@ class Type(Enum):
     CANCELLED = 4
     RUNNING = 5
 
+
 class ExecutionResult:
 
     # Result type, success or failure
     type: Type
 
-    # Execution context 
+    # Execution context
     context: ExecutionContext
 
     def __init__(self, ctx: ExecutionContext) -> None:
@@ -39,28 +40,44 @@ class ExecutionResult:
 
     def get_context(self) -> ExecutionContext:
         return self.context
-        
+
     def set_result_type(self, type: Type) -> None:
         self.type = type
 
     def get_result_type(self) -> Type:
-        return self.type 
+        return self.type
 
     def get_summary(self) -> str:
-        summary = "~~~~ Execution Summary ~~~~\n\n"
-        summary += f"{self.get_context().get_task_name()} - {self.get_context().get_report().as_string()}\n"
+        summary = (
+            f"~~~~ Execution Summary - {self.get_context().get_task_name()} ~~~~\n"
+        )
 
         if self.type == Type.FAILURE:
-            summary += "Execution finished with errors.\n"
+            summary += "Execution finished with errors."
         elif self.type == Type.CANCELLED:
-            summary += "Execution was cancelled by request.\n"
+            summary += "Execution was cancelled by request."
         else:
-            summary += "Execution finished successfully!\n"
+            summary += "Execution finished successfully!"
+        summary += "\n"
+
+        summary += f"{self.get_context().get_report().as_string()}\n"
+        summary += "\n"
+
+        structured_report = self.get_structured_report()
+        if structured_report is not None:
+            summary += f"~~~~ Ingestion Report ~~~~\n"
+            with contextlib.suppress(Exception):
+                # Try to reformat the structured report.
+                structured_report = json.dumps(json.loads(structured_report), indent=2)
+            summary += f"{structured_report}\n"
+            summary += "\n"
+
+        summary += f"~~~~ Ingestion Logs ~~~~\n"
+        summary += f"{self.get_context().get_report().get_logs()}\n"
         return summary
 
     def get_structured_report(self) -> Optional[str]:
-        return self.get_context().get_report().structured_report
-
+        return self.get_context().get_report().get_structured_report()
 
     def pretty_print_summary(self):
-        print(self.get_summary())
\ No newline at end of file
+        print(self.get_summary())
